==> invenio-2.0.0.tar.gz: invenio-2.0.0/invenio/modules/oauthclient/client.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2014 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

"""Registries of handlers for oauthclient."""

from flask_oauthlib.client import OAuth
from flask.ext.registry import DictRegistry, RegistryProxy

oauth = OAuth()
"""Flask-OAuthlib extension."""

handlers = RegistryProxy('oauthclientext.handlers', DictRegistry)
"""Registry of handlers for authorized handler callbacks."""

disconnect_handlers = RegistryProxy(
    'oauthclientext.disconnecthandlers', DictRegistry
)
"""Registry of handlers for authorized handler callbacks."""

signup_handlers = RegistryProxy(
    'oauthclientext.signuphandlers', DictRegistry
)
"""Registry of handlers for signup handlers."""

account_handlers = RegistryProxy(
    'oauthclientext.accounthandlers', DictRegistry
)
"""Registry of handlers for initializing an account."""

==> invenio-2.0.3.tar.gz: invenio-2.0.3/invenio/modules/oauthclient/client.py <==
# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2014, 2015 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

"""Registries of handlers for oauthclient."""

from flask_oauthlib.client import OAuth
from flask_registry import DictRegistry, RegistryProxy

oauth = OAuth()
"""Flask-OAuthlib extension."""

handlers = RegistryProxy('oauthclientext.handlers', DictRegistry)
"""Registry of handlers for authorized handler callbacks."""

disconnect_handlers = RegistryProxy(
    'oauthclientext.disconnecthandlers', DictRegistry
)
"""Registry of handlers for authorized handler callbacks."""

signup_handlers = RegistryProxy(
    'oauthclientext.signuphandlers', DictRegistry
)
"""Registry of handlers for signup handlers."""

account_handlers = RegistryProxy(
    'oauthclientext.accounthandlers', DictRegistry
)
"""Registry of handlers for initializing an account."""
